==> ckeditor_4.5.7+dfsg.orig.tar.xz: ckeditor-dev-4.5.7/plugins/forms/lang/hr.js <==
/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'forms', 'hr', {
	button: {
		title: 'Button svojstva',
		text: 'Tekst (vrijednost)',
		type: 'Vrsta',
		typeBtn: 'Gumb',
		typeSbm: 'Pošalji',
		typeRst: 'Poništi'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Checkbox svojstva',
		radioTitle: 'Radio Button svojstva',
		value: 'Vrijednost',
		selected: 'Odabrano',
		required: 'Required' // MISSING
	},
	form: {
		title: 'Form svojstva',
		menu: 'Form svojstva',
		action: 'Akcija',
		method: 'Metoda',
		encoding: 'Encoding'
	},
	hidden: {
		title: 'Hidden Field svojstva',
		name: 'Ime',
		value: 'Vrijednost'
	},
	select: {
		title: 'Selection svojstva',
		selectInfo: 'Info',
		opAvail: 'Dostupne opcije',
		value: 'Vrijednost',
		size: 'Veličina',
		lines: 'linija',
		chkMulti: 'Dozvoli višestruki odabir',
		required: 'Required', // MISSING
		opText: 'Tekst',
		opValue: 'Vrijednost',
		btnAdd: 'Dodaj',
		btnModify: 'Promijeni',
		btnUp: 'Gore',
		btnDown: 'Dolje',
		btnSetValue: 'Postavi kao odabranu vrijednost',
		btnDelete: 'Obriši'
	},
	textarea: {
		title: 'Textarea svojstva',
		cols: 'Kolona',
		rows: 'Redova'
	},
	textfield: {
		title: 'Text Field svojstva',
		name: 'Ime',
		value: 'Vrijednost',
		charWidth: 'Širina',
		maxChars: 'Najviše karaktera',
		required: 'Required', // MISSING
		type: 'Vrsta',
		typeText: 'Tekst',
		typePass: 'Šifra',
		typeEmail: 'Email',
		typeSearch: 'Traži',
		typeTel: 'Broj telefona',
		typeUrl: 'URL'
	}
} );

==> ckeditor_4.11.1+dfsg.orig.tar.xz: ckeditor-dev-4.11.1/plugins/forms/lang/hr.js <==
/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'forms', 'hr', {
	button: {
		title: 'Svojstva gumba',
		text: 'Tekst (vrijednost)',
		type: 'Vrsta',
		typeBtn: 'Gumb',
		typeSbm: 'Pošalji',
		typeRst: 'Poništi'
	},
	checkboxAndRadio: {
		checkboxTitle: 'Checkbox svojstva',
		radioTitle: 'Radio Button svojstva',
		value: 'Vrijednost',
		selected: 'Odabrano',
		required: 'Potrebno'
	},
	form: {
		title: 'Svojstva forme',
		menu: 'Svojstva forme',
		action: 'Akcija',
		method: 'Metoda',
		encoding: 'Encoding'
	},
	hidden: {
		title: 'Svojstva sakrivenog polja',
		name: 'Ime',
		value: 'Vrijednost'
	},
	select: {
		title: 'Svojstva selection polja',
		selectInfo: 'Info',
		opAvail: 'Dostupne opcije',
		value: 'Vrijednost',
		size: 'Veličina',
		lines: 'linija',
		chkMulti: 'Dozvoli višestruki odabir',
		required: 'Potrebno',
		opText: 'Tekst',
		opValue: 'Vrijednost',
		btnAdd: 'Dodaj',
		btnModify: 'Promijeni',
		btnUp: 'Gore',
		btnDown: 'Dolje',
		btnSetValue: 'Postavi kao odabranu vrijednost',
		btnDelete: 'Obriši'
	},
	textarea: {
		title: 'Textarea svojstva',
		cols: 'Kolona',
		rows: 'Redova'
	},
	textfield: {
		title: 'Svojstva tekst polja',
		name: 'Ime',
		value: 'Vrijednost',
		charWidth: 'Širina',
		maxChars: 'Najviše karaktera',
		required: 'Potrebno',
		type: 'Vrsta',
		typeText: 'Tekst',
		typePass: 'Šifra',
		typeEmail: 'Email',
		typeSearch: 'Traži',
		typeTel: 'Broj telefona',
		typeUrl: 'URL'
	}
} );
